#include <bits/stdc++.h>

using namespace std;

#define sz(a) (int)(a).size()

typedef long long ll;
typedef long double ld;

const ld eps = 1e-8;
const ld PI = atan2(0, -1);
bool eq(ld x, ld y)
{
    return abs(x - y) < eps;
}

bool Less(ld x, ld y)
{
    return x + eps < y;
}

bool notLess(ld x, ld y)
{
    return x + eps > y;
}

bool Greater(ld x, ld y)
{
    return x > y + eps;
}

bool notGreater(ld x, ld y)
{
    return x < y + eps;
}

ld sqr(ld x)
{
    return x * x;
}

ld Sqrt(ld x)
{
    if (x < -eps)
    {
        cerr << "SQRT OF NEGATIVE NUMBER" << endl;
        exit(0);
    }
    if (x < 0)
        return 0;
    return sqrt(x);
}

struct Point
{
    ll x, y;
    Point():
        x(0),
        y(0) {}

    Point(ll x, ll y):
        x(x),
        y(y) {}

    Point operator+(Point p)
    {
        return Point(p.x + x, p.y + y);
    }

    Point operator-(Point p)
    {
        return Point(x - p.x, y - p.y);
    }

    Point operator-()
    {
        return Point(-x, -y);
    }

    void operator+=(Point p)
    {
        x += p.x;
        y += p.y;
    }

    void operator-=(Point p)
    {
        x -= p.x;
        y -= p.y;
    }

    ll operator*(Point p)
    {
        return x * p.x + y * p.y;
    }

    ll operator^(Point p)
    {
        return x * p.y - y * p.x;
    }

    ll len()
    {
        return sqr(x) + sqr(y);
    }

    Point operator*(ll k)
    {
        return Point(k * x, k * y);
    }

    void operator*=(ll k)
    {
        x *= k;
        y *= k;
    }
};

struct Line
{
    ll a, b, c;
    Line():
        a(1),
        b(1),
        c(0) {}

    Line(ll a, ll b, ll c):
        a(a),
        b(b),
        c(c) {}

    Line(Point p, Point q):
        a(p.y - q.y),
        b(q.x - p.x),
        c(-a * p.x - b * p.y) {}

    ll operator()(Point p)
    {
        return p.x * a + p.y * b + c;
    }
};

pair<ld, ld> cross(Line l, Line k)
{
    ld ka = k.a;
    ld kb = k.b;
    ld kc = k.c;
    ld la = l.a;
    ld lb = l.b;
    ld lc = l.c;
    ld l1 = Sqrt(sqr(la) + sqr(lb) + sqr(lc));
    ld k1 = Sqrt(sqr(ka) + sqr(kb) + sqr(kc));
    ka /= k1;
    kb /= k1;
    kc /= k1;
    la /= l1;
    lb /= l1;
    lc /= l1;
    ld x = -(ld)((ld)k.b * (ld)l.c - (ld)l.b * (ld)k.c) / (ld)((ld)k.b * (ld)l.a - (ld)l.b * (ld)k.a);
    ld y = -(ld)((ld)k.a * (ld)l.c - (ld)l.a * k.c) / (ld)((ld)k.a * (ld)l.b - (ld)l.a * (ld)k.b);
    return {x, y};
}

bool parallel(Line l, Line k)
{
   // return (__int128)l.a * (__int128)k.b == (__int128)l.b * (__int128)k.a;
    return (ll)l.a * (ll)k.b == (ll)l.b * (ll)k.a;
}

const int N = 200001;

ll ch[N], zn[N];

int solve()
{
    ios::sync_with_stdio(0);
    int n;
    if (!(cin >> n))
        return 1;
    vector<Point> a(2 * n);
    for (int i = 0; i < 2 * n; i++)
        cin >> a[i].x >> a[i].y;
    int xx = 0;
    for (int y = 1; y < 2 * n; y++)
    {
        int z = 1;
        if (y == 1)
            z = 2;
        for (int t = 1; t < 2 * n; t++)
            if (t != z && t != y)
            {
                Line L = Line(a[xx], a[y]);
                Line K = Line(a[z], a[t]);
                pair<ld, ld> Pp = cross(L, K);
                ll x = Pp.first + eps;
                ll y = Pp.second + eps;
                ld xx = x;
                ld yy = y;
                if (abs(Pp.first) > 1e9 + eps || abs(Pp.second) > 1e9 + eps || parallel(L, K) || max(abs(x), abs(y)) > 1000000)
                    continue;
                Point P(x, y);
                for (int i = 0; i < 2 * n; i++)
                {
                    Point v = a[i] - P;
                    if (v.y < 0)
                        v.y = -v.y, v.x = -v.x;
                    if (v.y == 0 && v.x < 0)
                        v.x = -v.x;
                    ch[i] = v.x;
                    zn[i] = v.y;
                }
                bool ok = 1;
                bool ok1 = 1;
                for (int i = 0; i < 2 * n; i++)
                {
                    int cnt = 0;
                    for (int j = 0; j < 2 * n; j++)
                        if (ch[i] * zn[j] == ch[j] * zn[i])
                            cnt++;
                    if (cnt != 2)
                    {
                        ok = false;
                       // break;
                    }
                    if (P.x == a[i].x && P.y == a[i].y)
                        ok1 = false;
                }
                if ((1 || ok) && ok1)
                {
                    cout << "Yes\n";
                    cout << x << " " << y << endl;
                    return 0;
                }
            }
    }
    cout << "No\n";
    return 0;
}

//#define KEK
int main()
{
    #ifdef KEK
        freopen("in.txt", "r", stdin);
    #endif
    for (int i = 1;; i++)
    {
        #ifdef KEK
            cerr << "Test #" << i << endl;
        #endif
        if (solve())
            break;
    }
    #ifdef KEK
        cerr << "finished in " << clock() * 1000LL / CLOCKS_PER_SEC;
    #endif
    return 0;
}
