#define _CRT_SECURE_NO_WARNINGS
#include <iostream>
#include <vector>
#include <map>
#include <string>
#include <set>
#include <algorithm>
#include <cmath>
#include <complex>
using namespace std;

void fourier(vector < complex < double > > &v, long long mn = 2) {
	while (v.size() <= mn || (v.size() & (v.size() - 1)) != 0)
		v.push_back(0);
	long long len = v.size();
	long long k = log2(len);
	vector < long long > d(len);
	for (long long i = 0; i < len; i++)
		d[i] = ((d[i >> 1] >> 1) | ((i & 1) << k - 1));
	for (long long i = 0; i < len; i++)
		if (i < d[i])
			swap(v[i], v[d[i]]);
	for (long long l = 1; l < len; l *= 2) {
		complex < double > wd(cos(acos(-1) / l), sin(acos(-1) / l));
		for (long long i = 0; i < len; i += 2 * l) {
			complex < double > w(1, 0);
			for (long long j = 0; j < l; j++) {
				auto v1 = v[i + j];
				auto v2 = v[i + j + l];
				v[i + j] = v1 + v2 * w;
				v[i + j + l] = v1 - v2 * w;
				w *= wd;
			}
		}
	}
}

long long rnd() {
	return (rand() << 16) | rand();
}

long long rnd(long long l, long long r) {
	return l + rnd() % (r - l + 1);
}

struct node {
	node *l, *r;
	long long x, y;
	long long cnt;

	node() {
		l = r = NULL;
		x = 0;
		y = rnd();
		cnt = 1;
	}
	node(long long data) {
		l = r = NULL;
		x = data;
		y = rnd();
		cnt = 1;
	}
};

long long sz(node *v) {
	return !v ? 0 : v->cnt;
}

node * rec(node *v) {
	if (!v)
		return v;
	v->cnt = sz(v->l) + sz(v->r) + 1;
	return v;
}

node *merge(node *l, node *r) {
	if (!l || !r)
		return !l ? r : l;
	if (l->y > r->y) {
		l->r = merge(l->r, r);
		return rec(l);
	}
	r->l = merge(l, r->l);
	return rec(r);
}

pair < node*, node* > split(node *v, long long cnt) {
	if (!v)
		return{ NULL, NULL };
	if (sz(v->l) >= cnt) {
		auto p = split(v->l, cnt);
		v->l = p.second;
		return { p.first, rec(v) };
	}
	auto p = split(v->r, cnt - 1 - sz(v->l));
	v->r = p.first;
	return { rec(v), p.second };
}

void print(node *v) {
	if (!v)
		return;
	print(v->l);
	cout << v->x << ' ';
	print(v->r);
}

void println(node *v) {
#ifdef _DEBUG
	print(v);
	cout << endl;
#endif
}

void add(node *&root, long long value) {
	root = merge(root, new node(value));
}

const long long aholen = 1e2;
const long long alp = 26;
long long link[aholen][alp], go[aholen][alp], suf[aholen], suff[aholen], sym[aholen], ter[aholen], par[aholen];
long long root = 0;
long long tp = 0;

long long create() {
	for (long long i = 0; i < alp; i++)
		link[tp][i] = go[tp][i] = -1;
	suf[tp] = -1;
	suff[tp] = -1;
	sym[tp] = -1;
	ter[tp] = 0;
	return tp++;
}

void add(string &s) {
	long long pos = root;
	for (long long i = 0; i < s.size(); i++) {
		long long sm = s[i] - 'a';
		if (link[pos][sm] == -1) {
			long long f = create();
			link[pos][sm] = f;
			sym[f] = sm;
			par[f] = pos;
		}
		pos = link[pos][sm];
	}
	ter[pos]++;
}

long long gsuf(long long v);

long long ggo(long long v, long long s) {
	if (go[v][s] != -1)
		return go[v][s];
	if (link[v][s] != -1)
		return go[v][s] = link[v][s];
	if (v == root)
		return go[v][s] = root;
	return go[v][s] = ggo(gsuf(v), s);
}

long long gsuf(long long v) {
	if (suf[v] != -1)
		return suf[v];
	if (v == root || par[v] == root)
		return suf[v] = root;
	return suf[v] = ggo(gsuf(par[v]), sym[v]);
}

long long gsuff(long long v) {
	if (suff[v] != -1)
		return suff[v];
	if (v == root || par[v] == root)
		return suff[v] = root;
	if (ter[gsuf(v)] != 0)
		return suff[v] = gsuf(v);
	return suff[v] = gsuff(gsuf(v));
}

long long gcd(long long a, long long b) {
	return a == 0 ? b : gcd(b % a, a);
}

struct point {
	long long x, y;
};

istream &operator >> (istream &cin, point &p) {
	cin >> p.x >> p.y;
	return cin;
}

struct vec2 {
	long long x, y;
	vec2(point a, point b) {
		x = b.x - a.x;
		y = b.y - a.y;
	}
	vec2(long long a, long long b) {
		x = a;
		y = b;
	}
	void cut() {
		int g = gcd(abs(x), abs(y));
		if (g != 0) {
			x /= g;
			y /= g;
		} else {
			if (x == 0)
				y = y < 0 ? -1 : 1;
			else
				x = x < 0 ? -1 : 1;
		}
	}
};

point operator + (point a, vec2 b) {
	return {a.x + b.x, a.y + b.y};
}

vec2 operator * (vec2 a, long long d) {
	return {a.x * d, a.y * d};
}

bool operator == (vec2 a, vec2 b) {
	return a.x == b.x && a.y == b.y;
}

bool operator < (vec2 a, vec2 b) {
	if (a.x == b.x)
		return a.y < b.y;
	return a.x < b.x;
}

/*int x;
#ifndef _DEBUG
const int len = 3e5;
#else
const int len = 1e2;
#endif
vector < int > g[len];
int c[len], mn[len], sze[len];
long long sum[len];

long long ans = 0;

void dfs(int v) {
	sze[v] = 1;
	for (auto go : g[v]) {
		dfs(go);
		sze[v] += sze[go];
	}
	vector < int > s;
	for (auto go : g[v])
		s.push_back(sze[go]);
	sort(s.begin(), s.end());
}*/

const int len = 6e6;
string s;
int cnt[len];

int main() {
#ifdef _DEBUG
	freopen("input.txt", "r", stdin);
	freopen("output.txt", "w", stdout);
#endif
	cin >> s;
	vector < int > d;
	for (int i = 1; i <= s.size(); i++)
		if (s.size() % i == 0)
			d.push_back(i);

	vector < int > ans, now, next;

	for (int i = 0; i < 26; i++) {
		now.clear();
		for (int j = 0; j < s.size(); j++) {
			cnt[j] = 0;
			if (s[j] - 'a' == i)
				cnt[j]++;
			if (j - 1 >= 0)
				cnt[j] += cnt[j - 1];
		}

		int t = 0;
		if (i != 0)
			while (d[t] < ans[0])
				t++;

		for (t = 0; t < d.size(); t++) {
			bool bad = false;
			int ln = d[t];
			for (int j = ln - 1 + ln; j < s.size() && !bad; j += ln) {
					if (cnt[j] - cnt[j - ln] != cnt[ln - 1])
						bad = true;
			}
			if (!bad)
				now.push_back(ln);
		}
		if (i == 0) {
			ans = now;
		} else {
			next.clear();
			
			int l = 0, r = 0;
			while (l != ans.size() && r != now.size()) {
				while (l < ans.size() && ans[l] < now[r])
					l++;
				if (l == ans.size())
					break;
				while (r < now.size() && now[r] < ans[l])
					r++;
				if (r == now.size())
					break;
				if (ans[l] == now[r]) {
					next.push_back(ans[l]);
					l++;
					r++;
				}
			}

			ans.clear();
			for (auto el : next)
				ans.push_back(el);
		}
	}
	cout << s.size() / ans[0];
	/*for (int i = 0; i < d.size(); i++) {
		int ln = d[i];
		bool bad = false;
		for (int j = ln - 1 + ln; j < s.size() && !bad; j += ln) {
			for (int k = 0; k < 26; k++)
				if (cnt[j][k] - cnt[j - ln][k] != cnt[ln - 1][k])
					bad = true;
		}
		if (!bad) {
			cout << s.size() / d[i];
			return 0;
		}
	}*/
}