import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.Locale;
import java.util.StringTokenizer;

public class B {

    public long n;

    public static class Point {
        public long x, y;

        public Point(long x, long y) {
            this.x = x;
            this.y = y;
        }

        @Override
        public String toString() {
            return x + " " + y;
        }

        @Override
        public boolean equals(Object obj) {
            if (!(obj instanceof Point))
                return false;
            Point p = (Point) obj;
            return p.x == x && p.y == y;
        }
    }

    public static class Vector {
        public long x, y;

        public Vector(long x, long y) {
            this.x = x;
            this.y = y;
        }

        public Vector(Point a, Point b) {
            this(b.x - a.x, b.y - a.y);
        }

        @SuppressWarnings("SuspiciousNameCombination")
        public Vector rotate90() {
            return new Vector(-y, x);
        }
    }

    public static class Line {
        public long a, b, c;

        public Line(long a, long b, long c) {
            this.a = a;
            this.b = b;
            this.c = c;
        }

        @Override
        public boolean equals(Object obj) {
            Line l = (Line) obj;
            return l.a == a && l.b == b && c == l.c;
        }
    }

    public Line lineByPoints(Point p1, Point p2) {
        Vector AB = new Vector(p1, p2);
        Vector AB_ROTATED = AB.rotate90();
        long a = AB_ROTATED.x;
        long b = AB_ROTATED.y;
        long c = -a * p1.x - b * p1.y;
        return new Line(a, b, c);
    }

    public Point linesIntersect(Line l1, Line l2) {
        long a1 = l1.a;
        long b1 = l1.b;
        long c1 = l1.c;
        long a2 = l2.a;
        long b2 = l2.b;
        long c2 = l2.c;
        if ((a1 * b2 - a2 * b1) == 0)
            return null;
        if ((a2 * c1 - c2 * a1) % ((a1 * b2 - a2 * b1)) != 0)
            return null;
        long y = (a2 * c1 - c2 * a1) / (a1 * b2 - a2 * b1);
        if ((b1 * c2 - c1 * b2) % ((a1 * b2 - a2 * b1)) != 0)
            return null;
        long x = (b1 * c2 - c1 * b2) / (a1 * b2 - a2 * b1);
        return new Point(x, y);
    }

    public Point getIntersection(Point a1, Point a2, Point b1, Point b2) {
        Line l1 = lineByPoints(a1, a2);
        Line l2 = lineByPoints(b1, b2);
        if (l1.equals(l2))
            return null;
        Point res = linesIntersect(l1, l2);
        if (res == null)
            return null;
        if (res.equals(a1) || res.equals(a2) || res.equals(b1) || res.equals(b2))
            return null;
        return res;
    }

    public void solve() throws IOException {
        n = nextInt();
        if (n == 3) {
            out.print("Yes\n 2 2");
            return;
        }
        Point a = nextPoint();
        Point b = nextPoint();
        Point c = nextPoint();
        Point d = nextPoint();
        Point r1 = getIntersection(b, a, c, d);
        Point r2 = getIntersection(c, a, b, d);
        Point r3 = getIntersection(d, a, c, b);
        if (r1 != null) {
            out.println("Yes");
            out.print(r1);
            return;
        }
        if (r2 != null) {
            out.println("Yes");
            out.print(r2);
            return;
        }
        if (r3 != null) {
            out.println("Yes");
            out.print(r3);
            return;
        }
        out.print("No");
    }

    public void run() throws IOException {
        br = new BufferedReader(new FileReader("input.txt"));
        out = new PrintWriter("output.txt");
        solve();
        br.close();
        out.close();
    }

    public String nextToken() throws IOException {
        while (tokenizer == null || !tokenizer.hasMoreTokens()) {
            tokenizer = new StringTokenizer(br.readLine());
        }
        return tokenizer.nextToken();
    }

    public int nextInt() throws IOException {
        return Integer.parseInt(nextToken());
    }

    public long nextLong() throws IOException {
        return Long.parseLong(nextToken());
    }

    public double nextDouble() throws IOException {
        return Double.parseDouble(nextToken());
    }

    public Point nextPoint() throws IOException {
        return new Point(nextInt(), nextInt());
    }

    public BufferedReader br;
    public PrintWriter out;
    public StringTokenizer tokenizer;

    public static void main(String[] args) throws IOException {
        Locale.setDefault(Locale.US);
        new B().run();
    }
}
