#include <iostream>
#include <vector>
#include <algorithm>
#include <cmath>
#include <set>

using namespace std;
using ld = long long;

const long double eps = 1e-7;
const long double pi = acos(-1);
const ld INF = 10000000000000;

struct point {
	ld x, y;
	point(ld xx = 0, ld yy = 0) { x = xx, y = yy; }
};

struct vect {
	ld x, y;
	vect(ld xx = 0, ld yy = 0) { x = xx, y = yy; }
	vect(point a, point b) { x = b.x - a.x, y = b.y - a.y; }
};

struct line {
	ld a, b, c;
	line(ld aa = 0, ld bb = 0, ld cc = 0) { a = aa, b = bb, c = cc; }
	line(point p1, point p2) { a = p1.y - p2.y, b = p2.x - p1.x, c = p1.x * p2.y - p2.x * p1.y; }
};

bool operator ==(point a, point b) {
	return a.x == b.x && a.y == b.y;
}

ld cross(vect a, vect b) {
	return a.x * b.y - a.y * b.x;
}

/*bool integ(point& p) {
	if (abs(p.x - round(p.x)) < eps && abs(p.y - round(p.y)) < eps) {
		p.x = round(p.x), p.y = round(p.y);
		return 1;
	}
	return 0;
}*/

pair<point, bool> intersect(line l1, line l2) {
	if (l1.a * l2.b == l1.b * l2.a) return { point(), 0 };
	ld x1 = l2.c*l1.b - l1.c*l2.b, x2 = l2.b*l1.a - l1.b*l2.a, x3 = l2.c*l1.a - l1.c*l2.a, x4 = l1.b*l2.a - l2.b*l1.a;
	if (abs(x1) % abs(x2) != 0 || abs(x3) % abs(x4) != 0) return { point(), 0 };
	point ans(x1 / x2, x3 / x4);
	return { ans, 1 };
}

pair<point, bool> interseg(point p1, point p2, point p3, point p4) {
	line l1(p1, p2), l2(p3, p4);
	return intersect(l1, l2);
}

point null;

bool cmp(point a, point b) {
	vect v1 = vect(null, a), v2 = vect(null, b);
	return cross(v1, v2) > 0;
}

bool one_line(point a, point b) {
	vect v1 = vect(null, a), v2 = vect(null, b);
	return cross(v1, v2) == 0;
}

long double angle(vect v) {
	long double ang = atan2(v.y, v.x);
	if (ang >= pi) ang -= pi;
	if (ang < 0) ang += pi;
	return ang;
}

int main()
{
	cout.precision(20);
	int n;
	cin >> n;
	n *= 2;
	vector<point> a(n);
	for (int i = 0; i < n; i++) {
		cin >> a[i].x >> a[i].y;
	}
	int num1 = 0;
	point ans(INF, INF);
	for (int num2 = 1; num2 < n; num2++) {
		int num3 = num2 != 1 ? 1 : 2;
		for (int num4 = 1; num4 < n; num4++) {
			if (num4 == num2 || num4 == num3) continue;
			auto elem = interseg(a[num1], a[num2], a[num3], a[num4]);
			if (!elem.second) continue;
			null = elem.first;
			if (find(a.begin(), a.end(), null) != a.end()) continue;
			//cout << null.x << ' ' << null.y << endl;
			/*set<pair<long double, int> > s;
			set<long double> was;
			bool ok = 1;
			for (int i = 0; i < n; i++) {
				vect v = vect(null, a[i]);
				long double ang = angle(v);
				//cout << ang << ' ' << null.x << ' ' << null.y << ' ' << v.x << ' ' << v.y << endl;
				auto it = s.lower_bound(make_pair(ang - eps, 0));
				if (it == s.end() || abs((*it).first - ang) > eps) {
					s.insert({ angle(v), i });
				}
				else {
					auto it2 = was.lower_bound(ang - eps);
					if (it2 != was.end() && abs(*it2 - ang) < eps) {
						ok = 0;
						break;
					}
					s.erase(it);
					was.insert(ang);
				}
			}
			if (s.empty() && ok) {
				ans = null;
				break;
			}*/
			//vector<bool> used(n);
			bool ok = 1;
			for (int i = 0; i < n; i++) {
				int cnt = 0;
				for (int j = 0; j < n; j++) {
					if (j == i) continue;
					vect v1 = vect(null, a[i]);
					vect v2 = vect(null, a[j]);
					if (cross(v1, v2) == 0) cnt++;
				}
				if (cnt != 1) {
					ok = 0;
					break;
				}
			}
			if (ok) {
				ans = null;
				break;
			}
		}
		if (!(ans == point(INF, INF))) {
			break;
		}
	}
	if (ans == point(INF, INF)) {
		cout << "No" << endl;
	}
	else {
		cout << "Yes" << endl;
		cout << ans.x << ' ' << ans.y << endl;
	}
	return 0;
}

