#include <algorithm>
#include <iostream>
#include <vector>
#include <string>
#include <cmath>
#include <cassert>
#include <complex>

typedef long long db;
using namespace std;

struct v
{
    db x, y;
    v(db x, db y)
        : x(x), y(y)
    {}
    v() : x(0), y(0) {}
    v operator -(v b)
    {
        return v(x - b.x, y - b.y);
    }
    db operator %(const v& b)
    {
        return x * b.y - y * b.x;
    }
    bool operator <(const v& b) const
    {
        if (x != b.x)
            return x < b.x;
        return y < b.y;
    }
    bool operator ==(const v& b) const
    {
        return x == b.x && y == b.y;
    }
};

pair<double, double> inter(db x1, db y1, db x2, db y2, db x3, db y3, db x4, db y4)
{
    bool kek = x2 == x1;
    if (kek)
        swap(x1, y1), swap(x2, y2), swap(x3, y3), swap(x4, y4);
    double a = (y1 - y3) * (x4 - x3) - (x1 - x3) * (y4 - y3);
    a /= (y4 - y3 - (y2 - y1) * (x4 - x3) / (double)(x2 - x1));
    double b = a * (y2 - y1) / (double)(x2 - x1);
    if (kek)
        swap(a, b);
    return make_pair(x1 + a, y1 + b);
}

int n;
vector<v> pts;

double eps = 1e-7;

vector<v> getcand(int fir, int sec)
{
    vector<v> cand;
    int tri = sec + 1;
    if (tri == fir)
        ++tri;
    if (tri == n)
        tri = 0;
    if (tri == fir)
        ++tri;
    if (tri == n)
        tri = 0;
    for (int i = 0; i < n; ++i)
    {
        if (i == fir)
            continue;
        typedef complex<double> cp;
        db x1 = pts[fir].x, y1 = pts[fir].y, x2 = pts[i].x, y2 = pts[i].y;
        db x3, y3;
        if (i == sec)
            x3 = pts[tri].x, y3 = pts[tri].y;
        else
            x3 = pts[sec].x, y3 = pts[sec].y;
        int ind3 = i == sec ? tri : sec;
        for (int j = 0; j < n; ++j)
        {
            if (j == i || i == sec && j == tri || j == sec)
                continue;
            db x4 = pts[j].x, y4 = pts[j].y;
            if ((pts[i] - pts[fir]) % (pts[j] - pts[ind3]) == 0)
                continue;
            auto p = inter(x1, y1, x2, y2, x3, y3, x4, y4);
            db x = round(p.first), y = round(p.second);
            if (abs(x - p.first) > eps || abs(y - p.second) > eps)
                continue;
            cand.push_back({ x, y });
        }

    }
    return cand;
}

vector<v> inter(vector<v>& a, vector<v>& b)
{
    vector<v> c;
    for (auto& x : a)
    {
        auto it = lower_bound(b.begin(), b.end(), x);
        if (it != b.end() && *it == x)
            c.push_back(x);
    }
    return c;
}

int main()
{
    ios::sync_with_stdio(false);
    cin >> n;
    n *= 2;
    pts.resize(n);
    for (auto& x : pts)
        cin >> x.x >> x.y;
    random_shuffle(pts.begin(), pts.end());
    vector<v> cand = getcand(0, 1);
    vector<vector<v>> cand1 = { getcand(0, 2), getcand(1, 2) };
    sort(cand.begin(), cand.end());
    cand.resize(unique(cand.begin(), cand.end()) - cand.begin());
    for (auto& x : cand1)
    {
        sort(x.begin(), x.end());
        cand = inter(cand, x);
    }
    assert(cand.size() < 2000);
    for (auto& c : cand)
    {
        if (abs(c.x) > 1000000 || abs(c.y) > 1000000)
            continue;
        auto pts1 = pts;
        bool ok = true;
        for (auto& p : pts1)
        {
            if (p == c)
            {
                ok = false;
                break;
            }
            p.x -= c.x, p.y -= c.y;
        }
        if (!ok)
            continue;
        auto mem = [&](v pt)
        {
            if (pt.y < 0 || pt.y == 0 && pt.x < 0)
                pt.x = -pt.x, pt.y = -pt.y;
            return pt;
        };
        for (auto& x : pts1)
            x = mem(x);
        sort(pts1.begin(), pts1.end(), [&](v x, v y)
        {
            return x % y > 0;
        });
        int cur = 0;
        v last(1, -1);
        for (auto& p : pts1)
            if (p % last == 0)
            {
                if (++cur > 2)
                {
                    ok = false;
                    break;
                }
            }
            else
            {
                if (cur == 1)
                {
                    ok = false;
                    break;
                }
                last = p;
                cur = 1;
            }
        if (cur == 1)
            ok = false;
        if (ok)
        {
            cout << "Yes\n";
            cout << c.x << ' ' << c.y << '\n';
            return 0;
        }
    }
    cout << "No\n";
    //for (auto& x : cand)
    //    cerr << x.x << ' ' << x.y << '\n';
    system("pause");
}
/*
3
4 2
6 2
2 1
2 6
4 4
6 6
*/