#include <bits/stdc++.h>

#define int long long
#define pii pair<int, int>
#define ff first
#define ss second

using namespace std;

const double EPS = 1e-9;

struct vec
{
    double x, y;

    vec() {}
    vec(double _x, double _y) : x(_x), y(_y) {}
    ~vec() {}

    vec& operator = (const vec &r)
    {
        x = r.x;
        y = r.y;
        return *this;
    }

    vec operator + (const vec &r)
    {
        return vec(x + r.x, y + r.y);
    }

    vec operator - (const vec &r)
    {
        return vec(x - r.x, y - r.y);
    }

    vec operator * (const double &k)
    {
        return vec(x*k, y*k);
    }

    vec operator / (const double &k)
    {
        return vec(x/k, y/k);
    }

    double operator * (const vec &r)
    {
        return x*r.x + y*r.y;
    }

    double operator ^ (const vec &r)
    {
        return x*r.y - y*r.x;
    }

    double len()
    {
        return sqrt(x*x + y*y);
    }

    vec& normalize()
    {
        double l = len();
        x /= l;
        y /= l;
        return *this;
    }
};

struct line
{
    double a, b, c;
    vec A, B;
    line() {}
    line(double _a, double _b, double _c)
    {
        a = _a;
        b = _b;
        c = _c;

        if(b == 0)
        {
            double y1 = 0, y2 = 1;
            double x1 = -c/a;
            double x2 = -c/a;
            A = vec(x1, y1);
            B = vec(x2, y2);
        }
        else
        {
            double x1 = 0, x2 = 1;
            double y1 = (-c - a*x1)/b;
            double y2 = (-c - a*x2)/b;
            A = vec(x1, y1);
            B = vec(x2, y2);
        }
    }
    line(vec _A, vec _B)
    {
        A = _A;
        B = _B;

        double x1 = A.x, x2 = B.x, y1 = A.y, y2 = B.y;

        a = y2 - y1;
        b = x1 - x2;
        c = y1*x2 - x1*y2;
    }

    vec operator ^ (const line &r)
    {
        double a1 = a, b1 = b, c1 = c;
        double a2 = r.a, b2 = r.b, c2 = r.c;

        if(b1 == 0 && b2 == 0 || a1 == 0 && a2 == 0)
            return vec(-1e9, -1e9);

        if(b1 != 0 && b2 != 0 && -c1/b1 == -c2/b2)
            return vec(-1e9, -1e9);
        return vec((c2*a1 - c1*a2)/(b1*a2 - b2*a1), (c2*b1 - c1*b2)/(b2*a1 - b1*a2));
    }
};

bool operator == (const vec &l, const vec &r)
{
    return fabs(l.x - r.x) < EPS && fabs(l.y - r.y) < EPS;
}

line get_ort_line(vec p, line l)
{
    double x1 = p.x, y1 = p.y;
    double a = l.a, b = l.b, c = l.c;
    return line(-b, a, b*x1 - a*y1);
}

bool on_line(vec p, line l)
{
    return fabs(p^l.A) < EPS;
}

signed main()
{
    ios_base::sync_with_stdio(false);
    cout.tie(0);
    cin.tie(0);

    int n;
    cin >> n;
    n *= 2;

    vector<vec> data(n);
    for(int i = 0; i < n; i++)
        cin >> data[i].x >> data[i].y;

    if(n == 2)
    {
        vec v = data[1] - data[0];
        v = v*2;
        cout << v.x << " " << v.y;
        return 0;
    }

    for(int i = 0; i < n; i++)
    {
        for(int j = i + 1; j < n; j++)
        {
            for(int k = 0; k < n; k++)
            {
                for(int l = k + 1; l < n; l++)
                {
                    if(k == i || k == j || l == i || l == j)
                        continue;

                    line a(data[i], data[j]);
                    line b(data[k], data[l]);

                    vec am = data[j] - data[i];
                    vec bm = data[l] - data[k];

                    if(fabs(am^bm) < EPS)
                        continue;

                    vec inter = a^b;

                    if(floor(inter.x) != inter.x || floor(inter.y) != inter.y)
                        continue;

                    bool ok1 = true;
                    for(int i = 0; i < n; i++)
                        if(inter == data[i])
                            ok1 = false;

                    if(!ok1)
                        continue;

                    if(inter.x == -1e9 && inter.y == -1e9)
                        continue;

                    if(fabs(inter.x) > 1e6 || fabs(inter.y) > 1e6)
                        continue;

                    vector<bool> used(n, false);

                    used[i] = true;
                    used[j] = true;
                    used[k] = true;
                    used[l] = true;

                    bool ok = true;
                    for(int t = 0; t < n; t++)
                    {
                        if(used[t] || t == i || t == j || t == k || t == l)
                            continue;
                        for(int t1 = 0; t1 < n; t1++)
                        {
                            if(t == i || t == j || t == k || t == l || t == t1)
                                continue;
                            if(used[t] && !used[t1])
                            {
                                ok = false;
                                break;
                            }
                            if((line(data[t1], data[t])^a) == inter)
                            {
                                used[t] = true;
                                used[t1] = true;
                            }
                        }
                        if(!ok)
                            break;
                    }
                    if(!ok)
                        continue;

                    ok = true;
                    for(int i = 0; i < n; i++)
                        if(!used[i])
                            ok = false;

                    if(ok)
                    {
                        cout << "Yes" << endl << inter.x << " " << inter.y;
                        return 0;
                    }
                }
            }
        }
    }
    cout << "No";
    return 0;
}

/*!

2
0 0
1 1
-1 -1
-1 1

*/
