#include <bits/stdc++.h>

using namespace std;

typedef long long ll;

const double PI = acos(-1);
const double EPS = 1e-9;
const ll INF = (ll)1e6;

typedef double _float128;

const ll MAX = (ll)-1e18;


struct Point {
    ll x, y;
    Point(): x(0), y(0) {}

    Point(ll x, ll y): x(x), y(y) { }
    Point operator-(const Point &p) const {
        return Point (x - p.x, y - p.y);
    }
};

double getK(const Point&A, const Point &B) {
    Point v = B - A;
    if (v.x == 0) {
        return MAX;
    }
    return double(v.y) / double(v.x);
}

struct Line {
    ll a, b, c;
    Line(const Point &A, const Point &B) {
        a = A.y - B.y;
        b = B.x - A.x;
        c = -a * A.x - b * A.y;
    }
    bool operator==(const Line &l) const {
        return a * l.c == l.a * c && b * l.c == l.b * c;
    }
};

ll intersection(const Point &A, const Point &B, const Point &C, const Point &D, Point &O) {
    Line a(A, B), b(C, D);
    if (a.a * b.b == a.b * b.a) {
        return 0;
    }
    ll up = a.a * b.c - b.a * a.c;
    ll down = a.b * b.a - b.b * a.a;
    if (up % down != 0) {
        return 0;
    }
    O.y = up / down;
    if (a.a == 0) {
        if ((-b.c - b.b * O.y) % b.a != 0) {
            return 0;
        }
        O.x = (-b.c - b.b * O.y) / b.a;
    } else {
        if ((-a.c - a.b * O.y) % a.a != 0) {
            return 0;
        }
        O.x = (-a.c - a.b * O.y) / a.a;
    }
    return 1;
}

istream &operator>>(istream &in, Point &p) {
    in >> p.x >> p.y;
    return in;
}

bool check(Point O) {
    return abs(O.x) <= INF && abs(O.y) <= INF;
}

map<pair<ll, ll>, bool> exist;

void solve(vector<Point> &pts) {
    int n = pts.size();
    Point A = pts[0];
    for (int i = 2; i < n; ++i) {
        Point B = pts[i];
        Point C = pts[1];
        for (int j = 2; j < n; ++j) {
            if (j == i) {
                continue;
            }
            Point D = pts[j];
            Point O;
            ll k = intersection(A, B, C, D, O);
            if (!k || !check(O)) {
                continue;
            }
            if (exist.count({O.x, O.y}) != 0) {
                continue;
            }
            bool fl = 0;
            map<double, pair<ll, vector<Line>>> data;
            for (int l = 2; l < n; ++l) {
                if (l == i || l == j) {
                    continue;
                }
                double K = getK(pts[l], O);
                data[K].first++;
                data[K].second.emplace_back(pts[i], O);
            }
            for (auto x: data) {
                if (x.second.first % 2 != 0) {
                    fl = 1;
                    break;
                }
            }
            if (!fl) {
                assert(exist.count({O.x, O.y}) == 0);
                assert(check(O) == 1);
                cout << "Yes\n";
                cout << O.x << " " << O.y << "\n";
                exit(0);
            }
        }
    }
}

int main() {
    freopen("input.txt", "r", stdin);
    freopen("output.txt", "w", stdout);
    ios_base::sync_with_stdio(0);
    cin.tie(0);
    cout.tie(0);
    int n;
    cin >> n;
    vector<Point> pts(2 * n);
    for (auto &p: pts) {
        ll a, b;
        cin >> a >> b;
        exist[{a, b}] = 1;
        p = Point(a, b);
    }
    solve(pts);
    swap(pts[1], pts[2]);
    solve(pts);
    cout << "No\n";
}