#include <iostream>
#include <vector>
#include <bitset>
#include <cassert>
#include <algorithm>
#include <map>
#include <set>

using namespace std;
typedef unsigned int index;

struct Point
{
    int x, y;
    Point(int nx, int ny): x(nx), y(ny){}
    Point(){}
    friend bool operator <(const Point &a, const Point &b)
    {
        return (a.x < b.x or (a.x == b.x and a.y < b.y));
    }
    friend bool operator ==(const Point &a, const Point &b)
    {
        return a.x == b.x and a.y == b.y;
    }
};

long long gcd(long long a, long long b)
{
    long long c;
    while (a != 0)
    {
        c = a;
        a = b % a;
        b = c;
    }
    return b;
}

struct Line
{
    long long a, b, c;
    long long operator[](Point x)
    {
        return a * x.x + b * x.y + c;
    }
    Line(Point f, Point s)
    {
        a = f.y - s.y;
        b = s.x - f.x;
        c = -((long long)f.y * s.x - (long long)f.x * s.y);
        if (a < 0)
        {
            a *= -1;
            b *= -1;
            c *= -1;
        }
        else if (a == 0 and b < 0)
        {
            a *= -1;
            b *= -1;
            c *= -1;
        }
        long long g = gcd(gcd(a, b), c);
        a /= g;
        b /= g;
        c /= g;
    }
    friend bool operator <(const Line &a, const Line &b)
    {
        return (a.a < b.a or (a.a == b.a and (a.b < b.b or (a.b == b.b and a.c < b.c))));
    }
    friend bool operator ==(const Line &a, const Line &b)
    {
        return a.a == b.a and a.b == b.b and a.c == b.c;
    }
};

pair<bool, Point> isect(Line f, Line s)
{
    const static int MAXMOD = (int)1e6;
    Point ans;
    {
        long long bot = -f.a * s.b + f.b * s.a;
        long long top = f.b * s.c - f.c * s.b;
        if (bot == 0)
            return {false, Point()};
        ans.x = -(int)(top / bot);
    }
    {
        long long bot = f.a * s.b - f.b * s.a;
        long long top = f.a * s.c - f.c * s.a;
        if (bot == 0)
            return {false, Point()};
        ans.y = -(int)(top / bot);
    }
    if (abs(ans.x) > MAXMOD or abs(ans.y) > MAXMOD)
        return {false, Point()};
    if (f[ans] != 0 or s[ans] != 0)
        return {false, Point()};
    return {true, ans};
}

void add(vector<Point> &a, vector<Point> &ans)
{
    size_t n = a.size();
    for (index i = 2; i < n; i++)
        for (index j = 2; j < n; j++)
        {
            if (i != j)
            {
                Line f(a[0], a[i]), s(a[1], a[j]);
                auto x = isect(f, s);
                if (x.first)
                    ans.push_back(x.second);
            }
        }
    for (index i = 3; i < n; i++)
    {
        Line f(a[0], a[1]), s(a[2], a[i]);
        auto x = isect(f, s);
        if (x.first)
            ans.push_back(x.second);
    }
}


bool check(Point x, const vector<Point> &a)
{
    vector<Line> ans;
    for (auto i: a)
    {
        if ((i.x == x.x and i.y == x.y))
            return false;
        ans.push_back(Line(x, i));
    }
    sort(ans.begin(), ans.end());
    size_t cur = 1;
    for (index i = 1; i < ans.size(); i++)
    {
        if (ans[i] == ans[i - 1])
        {
            cur++;
            if (cur > 2)
                return false;
        }
        else
        {
            if (cur != 2)
                return false;
            cur = 1;
        }
    }
    return true;
}

int main()
{
    //assert(freopen("C:\\Users\\olymp\\Olymp\\a.in", "r", stdin));
    //assert(freopen("C:\\Users\\olymp\\Olymp\\a.out", "w", stdout));
    size_t n;
    cin >> n;
    n *= 2;
    vector<Point> a(n);
    for (auto &i: a)
        cin >> i.x >> i.y;
    random_shuffle(a.begin(), a.end());
    vector<Point> ans, ans2, ans3;
    add(a, ans);
    swap(a[0], a[2]);
    swap(a[1], a[3]);
    add(a, ans2);
    swap(a[0], a[n - 2]);
    swap(a[1], a[n - 1]);
    add(a, ans3);
    set<Point> f(ans.begin(), ans.end()), s(ans2.begin(), ans2.end()), t(ans3.begin(), ans3.end());
    set<Point> cool;
    for (auto i: f)
        if (s.count(i) != 0 and t.count(i) != 0)
            cool.insert(i);
    for (auto i: cool)
    {
        if (check(i, a))
        {
            cout << "Yes" << endl;
            cout << i.x << " " << i.y << endl;
            return 0;
        }
    }
    cout << "No" << endl;
}
