//
// Created by olymp on 09.03.2018.
//
#include <algorithm>
#include <iostream>
#include <unordered_map>
#include <vector>

using ll = long long;

struct point {
    ll x;
    ll y;
    point(): x(0), y(0) {}
    point(ll x, ll y): x(x), y(y) {}

    bool operator==(const point &other) const {
        return x == other.x && y == other.y;
    }

    bool operator<(const point &other) const {
        return x < other.x || (x == other.x && y < other.y);
    }

    point operator-() const {
        return {-x, -y};
    }

    point operator+(const point &other) const {
        return {x + other.x, y + other.y};
    }

    point operator-(const point &other) const {
        return *this + (-other);
    }
};

struct line {
    ll a;
    ll b;
    ll c;
    line(): a(0), b(0), c(0) {}
    line(const point &pt1, const point &pt2) {
        a = pt2.y - pt1.y;
        b = pt1.x - pt2.x;
        c = -a * pt1.x - b * pt1.y;
    }
};

bool isIntersect(const line &l1, const line &l2) {
    if (l1.a * l2.b == l1.b * l2.a) {
        return false;
    }
    if ((l1.a * l2.c - l1.c * l2.a) % (l1.b * l2.a - l2.b * l1.a) != 0) {
        return false;
    }
    if (((l2.c * l1.b - l1.c * l2.b) % (l1.a * l2.b - l2.a * l1.b)) != 0) {
        return false;
    }
    return true;
}

point intersect(const line &l1, const line &l2) {
    ll y = (l1.a * l2.c - l1.c * l2.a) / (l1.b * l2.a - l2.b * l1.a);
    ll x = (l2.c * l1.b - l1.c * l2.b) / (l1.a * l2.b - l2.a * l1.b);
    return {x, y};
}

std::istream& operator>>(std::istream &in, point &pt) {
    return in >> pt.x >> pt.y;
}

std::ostream& operator<<(std::ostream &out, const point &pt) {
    return out << pt.x << ' ' << pt.y;
}

int n = 0;
std::vector<point> a;

class Hash{
  public:
    size_t operator() (const point &p) const {
        return size_t(p.x ^ p.y);
    }
};

ll GCD(ll a, ll b) {
    return (b ? GCD(b, a % b) : a);
}

bool IsMoon(const point &p) {
    if (std::abs(p.x) > 1000000 || std::abs(p.y) > 1000000) {
        return false;
    }
    for (size_t i = 0; i < a.size(); ++i) {
        if (a[i] == p) {
            return false;
        }
    }
    std::unordered_map<point, int, Hash> um;
    um.rehash((size_t) n);
    for (size_t i = 0; i < a.size(); ++i) {
        point cur = a[i] - p;
        ll gcd = GCD(std::abs(cur.x), std::abs(cur.y));
        cur.x /= gcd;
        cur.y /= gcd;
        if (cur.x < 0 || (cur.x == 0 && cur.y < 0)) {
            cur = -cur;
        }
        um[cur] += 1;
        if (um[cur] > 2) {
            return false;
        }
    }
    for (auto i : um) {
        if (i.second != 2) {
            return false;
        }
    }
    return true;
}

int main() {
    std::cin >> n;
    a.resize((size_t) 2 * n);
    for (size_t i = 0; i < a.size(); ++i) {
        std::cin >> a[i];
    }
    line l(a[0], a[1]);
    for (size_t i = 2; i < a.size(); ++i) {
        for (size_t j = i + 1; j < a.size(); ++j) {
            line l1(a[i], a[j]);
            if (isIntersect(l, l1)) {
                point pt = intersect(l, l1);
                if (IsMoon(pt)) {
                    std::cout << "Yes\n" << pt;
                    return 0;
                }
            }
        }
    }
    for (size_t i = 0; i < a.size(); ++i) {
        for (size_t j = 0; j < a.size(); ++j) {
            if (i == 0 || j == 1 || i == j) {
                continue;
            }
            line l1(a[0], a[i]), l2(a[1], a[j]);
            if (isIntersect(l1, l2)) {
                point pt = intersect(l1, l2);
                if (IsMoon(pt)) {
                    std::cout << "Yes\n" << pt;
                    return 0;
                }
            }
        }
    }
    std::cout << "No";
    return 0;
}
