#include <bits/stdc++.h>

using namespace std;

#define int int64_t

template<typename _T>
inline void _DBG(const char *s, _T x);

template<typename _T, typename... args>
void _DBG(const char *s, _T x, args... a);

#ifdef LOCAL
#define DBG(...) _DBG(#__VA_ARGS__, __VA_ARGS__)
#else
#define endl "\n"
#define DBG(...) (true)
#define cerr if(0) cout
#endif

template<typename type>
istream &operator>>(istream &in, vector<type> &a);

template<typename type>
ostream &operator<<(ostream &out, const vector<type> &a);

ostream &operator<<(ostream &out, const vector<int> &a);

ostream &operator<<(ostream &out, const vector<double> &a);

ostream &operator<<(ostream &out, const vector<bool> &a);

template<typename type1, typename type2>
ostream &operator<<(ostream &out, const pair<type1, type2> &a);

template<typename type1, typename type2>
istream &operator>>(istream &in, pair<type1, type2> &a);

template<typename T, typename... args>
T max(const T &, args...);

template<typename T>
T max(const T &, const T &, const T &);

template<typename T>
T pow2(const T &);

template<typename T>
T Power(const T &, int, const T &);


// ********************** CODE ********************** //

const long double EPS = 1e-8;

int gcd(int a, int b) {
    return b == 0 ? a : gcd(b, a % b);
}

struct Vector;

struct Point {
    int x;
    int y;

    Point() : x(0), y(0) {}

    Point(int x1, int y1) : x(x1), y(y1) {}

    Point(Vector);
};

struct Vector {
    int x;
    int y;

    Vector() : x(0), y(0) {}

    Vector(int x1, int y1) : x(x1), y(y1) {}

    Vector(Point a, Point b) : x(b.x - a.x), y(b.y - a.y) {}

    Vector(Point a) : x(a.x), y(a.y) {}
};

istream &operator>>(istream &in, Point &a) {
    in >> a.x >> a.y;
    return in;
}

ostream &operator<<(ostream &out, const Point &a) {
    out << a.x << " " << a.y;
    return out;
}

istream &operator>>(istream &in, Vector &a) {
    in >> a.x >> a.y;
    return in;
}

ostream &operator<<(ostream &out, const Vector &a) {
    out << a.x << " " << a.y;
    return out;
}

Point::Point(Vector v) : x(v.x), y(v.y) {}

struct Line {
    Point s;
    Vector v;

    Line() : s(Point()), v(Vector()) {}

    Line(Point a, Point b) : s(a), v(Vector(a, b)) {}
};

int operator * (Vector a, Vector b) {
    return a.x * b.x + a.y * b.y;
}

int operator % (Vector a, Vector b) {
    return a.x * b.y - a.y * b.x;
}

bool isInLine(Point a, Line b) {
    return Vector(a, b.s) % b.v == 0;
}

Point operator + (Point a, Vector b) {
    return Point(a.x + b.x, a.y + b.y);
}

Point operator - (Point a, Vector b) {
    return Point(a.x - b.x, a.y - b.y);
}

bool intersection(Line l1, Line l2, Point& res) {
    int pr = l1.v % l2.v;
    if (pr == 0) {
        return false;
    }
    if (l1.v.x == 0) {
        swap(l1, l2);
        pr = -pr;
    }
    int tmpy = l1.s.y * l1.v.x + l2.s.x * l1.v.y - l1.s.x * l1.v.y - l2.s.y * l1.v.x;
    if (l2.v.x * tmpy % pr != 0 || l2.v.y * tmpy % pr != 0) {
        return false;
    }
    int tmpx = l2.s.x + l2.v.x * tmpy / pr;
    tmpy = l2.s.y + l2.v.y * tmpy / pr;
    res = Point(tmpx, tmpy);
    return true;
}

bool operator == (const Point& a, const Point& b) {
    return a.x == b.x && a.y == b.y;
}

signed main() {
    ios::sync_with_stdio(false);
    cin.tie(0);
    cout.tie(0);
    int n;
    cin >> n;
    n *= 2;
    vector<Point> a(n);
    mt19937 mtrnd;
    cin >> a;
    shuffle(a.begin(), a.end(), mtrnd);
    for (int i = 0; i < n; ++i) {
        for (int j = 0; j < n; ++j) {
            if (i == j) {
                continue;
            }
            Line l1(a[i], a[j]);
            for (int k = 0; k < n; ++k) {
                if (k == i || k == j) {
                    continue;
                }
                if (isInLine(a[k], l1)) {
                    continue;
                }
                for (int l = 0; l < n; ++l) {
                    if (l == k || l == i || l == j) {
                        continue;
                    }
                    Line l2(a[l], a[k]);
                    if (l1.v % l2.v == 0) {
                        continue;
                    }
                    Point kp;
                    if (!intersection(l1, l2, kp) || abs(kp.x) > 1000000 || abs(kp.y > 1000000)) {
                        continue;
                    }
                    bool flag = true;
                    for (int m = 0; m < n; ++m) {
                        if (kp == a[m]) {
                            flag = false;
                            break;
                        }
                        Line l3(kp, a[m]);
                        int summm = 0;
                        for (int o = 0; o < n && summm < 3; ++o) {
                            if (isInLine(a[o], l3)) {
                                ++summm;
                            }
                        }
                        if (summm != 2) {
                            flag = false;
                            break;
                        }
                    }
                    if (flag) {
                        cout << "Yes" << endl << kp << endl;
                        return 0;
                    }
                }
            }
        }
    }
    cout << "No" << endl;
    return 0;
}


// ********************* END OF CODE ********************* //


template<typename T>
T Power(const T &a, int n, const T &mod) {
    if (n == 0) {
        return 1;
    }
    if (n % 2) {
        return (a * Power(a, n - 1, mod)) % mod;
    }
    T res = Power(a, n / 2, mod);
    return (res * res) % mod;
}

template<typename T>
T pow2(const T &a) {
    return a * a;
}

template<typename _T>
inline void _DBG(const char *s, _T x) {
    cerr << s << " = " << x << "\n";
}

template<typename _T, typename... args>
void _DBG(const char *s, _T x, args... a) {
    int b = 0;
    while (*s != ',' || b != 0) {
        b += (*s) == '(';
        b -= (*s) == ')';
        cerr << *s++;
    }
    cerr << " = " << x << ',';
    _DBG(s + 1, a...);
}

template<typename T>
T max(const T &a) {
    return a;
}


template<typename T>
T max(const T &a, const T &b, const T &c) {
    return max(max(a, b), c);
}


template<typename T, typename... args>
T max(const T &a, args... b) {
    T res = ::max(b...);
    return a > res ? a : res;
}

ostream &operator<<(ostream &out, const vector<bool> &a) {
    for (auto x : a) {
        out << x << " ";
    }
    return out;
}

template<typename type1, typename type2>
istream &operator>>(istream &in, pair<type1, type2> &a) {
    in >> a.first >> a.second;
    return in;
}

template<typename type1, typename type2>
ostream &operator<<(ostream &out, const pair<type1, type2> &a) {
    out << a.first << " " << a.second;
    return out;
}

ostream &operator<<(ostream &out, const vector<double> &a) {
    for (auto &x : a) {
        out << x << " ";
    }
    return out;
}

ostream &operator<<(ostream &out, const vector<int> &a) {
    for (auto &x : a) {
        out << x << " ";
    }
    return out;
}

template<typename type>
ostream &operator<<(ostream &out, const vector<type> &a) {
    for (auto &x : a) {
        out << x << endl;
    }
    return out;
}

template<typename type>
istream &operator>>(istream &in, vector<type> &a) {
    for (auto &x : a) {
        in >> x;
    }
    return in;
}

