#include <iostream>
#include <vector>
#include <algorithm>


using namespace std;


using ld = long double;


const ld EPS = 1e-8;
const ld INF = 1e6;


bool integer(ld x) {
    return abs(x - (ld)(int)x) < EPS;
}


struct Point {
    ld x, y;

    Point() : x(0), y(0) {};
    Point(ld _x, ld _y) : x(_x), y(_y) {};

    bool operator==(const Point &p) const {
        return abs(x - p.x) < EPS && abs(y - p.y) < EPS;
    }
};

istream& operator>>(istream &in, Point &p) {
    return in >> p.x >> p.y;
}

ostream& operator<<(ostream &out, const Point &p) {
    return out << (int)p.x << ' ' << (int)p.y;
}


struct Line {
    Point a, b;

    Line() {};
    Line(const Point &_a, const Point &_b) : a(_a), b(_b) {};
};


bool on_line(const Line &n, const Point &p) {
    ld dx = n.a.x - n.b.x, dy = n.a.y - n.b.y;
    ld px = n.a.x - p.x, py = n.a.y - p.y;

    return abs(dx * py - px * dy) < EPS;
}


bool do_cross(const Line &n, const Line &m) {
    ld nx = n.a.x - n.b.x, ny = n.a.y - n.b.y;
    ld mx = m.a.x - m.b.x, my = m.a.y - m.b.y;

    return abs(nx * my - mx * ny) > EPS;
}


Point cross_point(Line n, Line m, bool &success) {
    if (!do_cross(n, m)) {
        success = false;

        return Point();
    }

    ld nx = n.a.x - n.b.x, ny = n.a.y - n.b.y;
    ld mx = m.a.x - m.b.x, my = m.a.y - m.b.y;

    if (abs(nx) < EPS || abs(mx) < EPS) {
        if (abs(mx) < EPS) {
            swap(nx, mx);
            swap(ny, my);
            swap(n, m);
        }

        ld mk = my / mx;
        ld mb = -mk * m.a.x + m.a.y;

        ld py = mk * n.a.x + mb;

        if (py > INF || !integer(py)) {
            success = false;

            return Point();
        }

        success = true;

        return Point(n.a.x, py);
    }

    ld nk = ny / nx;
    ld nb = -nk * n.a.x + n.a.y;

    ld mk = my / mx;
    ld mb = -mk * m.a.x + m.a.y;

    ld x = (mb - nb) / (nk - mk);
    ld y = nk * x + nb;

    if (x > INF || !integer(x) || y > INF || !integer(y)) {
        success = false;

        return Point();
    }

    success = true;
    return Point(x, y);
}


int main() {
    int n;
    cin >> n;

    n *= 2;

    vector<Point> stars(n);
    for (int i = 0; i < n; ++i) {
        cin >> stars[i];
    }

    vector<int> perebor(n, 0);
    perebor[n - 1] = perebor[n - 2] = 2;
    perebor[n - 3] = perebor[n - 4] = 1;

    vector<int> used(n);
    for (int i = 0; i < n - 1; ++i) {
        for (int j = i + 1; j < n; ++j) {
            used.assign(n, 0);
            used[i] = used[j] = true;

            for (int k = 0; k < n - 1; ++k) {
                for (int c = k + 1; c < n; ++c) {
                    if (used[k] || used[c]) {
                        continue;
                    }

                    vector<int> cused = used;
                    cused[k] = cused[c] = true;

                    Line l1(stars[i], stars[j]), l2(stars[k], stars[c]);

                    bool s;
                    Point p = cross_point(l1, l2, s);

                    if (!s) {
                        continue;
                    }

                    for (int cur = 0; cur < n; ++cur) {
                        if (p == stars[cur] || !cused[cur] && (on_line(l1, stars[cur]) || on_line(l2, stars[cur]))) {
                            s = false;
                            break;
                        }
                    }

                    if (!s) {
                        continue;
                    }

                    for (int cur = 0; cur < n; ++cur) {
                        if (cused[cur]) {
                            continue;
                        }

                        cused[cur] = true;

                        Line cl(p, stars[cur]);

                        int cross_cnt = 0;
                        for (int tcur = cur + 1; tcur < n; ++tcur) {
                            if (on_line(cl, stars[tcur])) {
                                cused[tcur] = true;
                                ++cross_cnt;

                                if (cross_cnt > 1) {
                                    break;
                                }
                            }
                        }

                        if (cross_cnt != 1) {
                            s = false;
                            break;
                        }
                    }

                    if (!s) {
                        continue;
                    }

                    if (abs(p.x) > INF || abs(p.y) > INF) {
                        continue;
                    }

                    cout << "Yes" << '\n' << p;

                    return 0;
                }
            }
        }
    }

    cout << "No";

    return 0;
}