#include <iostream>
#include <algorithm>
#include <fstream>
#include <ctime>
#include <cstring>

using namespace std;

inline int gcd(int x, int y)
{
    while (y)
    {
        swap(x, y);
        y %= x;
    }
    return x;
}

inline long long lgcd(long long x, long long y)
{
	while (y)
	{
		swap(x, y);
		y %= x;
	}
	return x;
}

const int broken = 1e6 + 5;
const int lim = 1e6;

struct Vector
{
    int x, y;
    explicit Vector(int x = 0, int y = 0) : x(x), y(y) {};
    inline Vector operator -()
    {
        return Vector(-x, -y);
    }
    inline Vector normalize()
    {
        if (!(x || y))
            return Vector(0, 0);
        int d = gcd(abs(x), abs(y));
        if (x > 0 || (x == 0 && y > 0))
            return Vector(x / d, y / d);
        return Vector(-x / d, -y / d);
    }
    inline bool good() const
    {
        return abs(x) <= lim && abs(y) <= lim;
    }
    inline operator bool() const
    {
        return x || y;
    }
};

inline Vector operator +(const Vector &A, const Vector &B)
{
    return Vector(A.x + B.x, A.y + B.y);
}

inline Vector operator -(const Vector &A, const Vector &B)
{
    return Vector(A.x - B.x, A.y - B.y);
}

inline bool operator < (const Vector&A, const Vector&B)
{
    return A.x == B.x ? A.y < B.y : A.x < B.x;
}

inline bool operator == (const Vector&A, const Vector&B)
{
    return A.x == B.x && A.y == B.y;
}

inline bool operator != (const Vector&A, const Vector&B)
{
    return A.x != B.x || A.y != B.y;
}

struct line
{
    long long a, b, c;
    explicit line(int a = 0, int b = 0, int c = 0) : a(a), b(b), c(c) {};
    explicit line(const Vector &A, const Vector &B)
    {
        a = B.y - A.y;
        b = A.x - B.x;
        c = -a * A.x - b * A.y;
    }
    inline int operator()(int x) const
    {
        long long val = - a * x - c;
		if (abs(val) > abs(b) * lim)
			return broken;
        if (val % b)
            return broken;
        return val / b;
    }
	inline long long operator()(Vector x) const
	{
		return a * x.x + b * x.y + c;
	}
	inline line normalize()
	{
		bool sign = (a == 0 ? b > 0 : a > 0);
		int d = lgcd(lgcd(abs(a), abs(b)), abs(c));
		if (sign)
			return line(a / d, b / d, c / d);
		else
			return line(-a / d, -b / d, -c / d);
	}
};

inline bool operator < (const line &f, const line &g)
{
	if (f.a == g.a)
		if (f.b == g.b)
			return f.c < g.c;
		else
			return f.b < g.b;
	return f.a < g.a;
}

inline bool operator == (const line &f, const line &g)
{
	return f.a == g.a && f.b == g.b && f.c == g.c;
}

inline Vector cross(const line &f, const line &g)
{
    long long A = f.a * g.b - f.b * g.a;
    if (!A)
        return Vector(broken);
    long long C = g.c * f.b - f.c * g.b;
	if (abs(C) > abs(A) * lim)
		return Vector(broken);
	if (C % A)
        return Vector(broken);
    int x = C / A;
    if (f.b)
        return Vector(x, f(x));
    else
        return Vector(x, g(x));
}

const int maxn = 3000;
Vector arr[maxn];
line lines[maxn * maxn];
const int mem_sz = 2 * lim + 1;
int mem1[mem_sz] = {};
int* cnt = mem1 + lim;

int main()
{
	srand(88005553535);
    ifstream cin("input.txt");
    int n;
    cin >> n;
	int n0 = n - 1;
    n *= 2;
    for (int i = 0; i < n; i++)
        cin >> arr[i].x >> arr[i].y;
	random_shuffle(arr, arr + n);
	int lcnt = 0;
	for (int i = 1; i < n; i++)
		for (int j = i + 1; j < n; j++)
			lines[lcnt++] = line(arr[i], arr[j]).normalize();
	sort(lines, lines + lcnt);
	lcnt = unique(lines, lines + lcnt) - lines;
    //int a = rand() % n;
	int a = 0;
    for (int i = 0; i < n; i++) if (i != a)
    {
        line l(arr[a], arr[i]);
		memset(mem1, 0, mem_sz * sizeof(int));
		bool f = 1;
		for (int j = 0; j < n; j++) if (j != a && j != i)
			if (l(arr[j]) == 0)
			{
				f = 0;
				break;
			}
		if (!f)
			continue;
		for (int j = 0; j < lcnt; j++)
		{
			Vector O = cross(l, lines[j]);
			if (!O.good())
				continue;
			if (O.x == arr[a].x || O.x == arr[i].x)
				continue;
			if (l.b)
			{
				if (++cnt[O.x] == n0)
				{
					cout << "Yes\n" << O.x << " " << O.y;
					return 0;
				}
			}
			else
				if (++cnt[O.y] == n0)
				{
					cout << "Yes\n" << O.x << " " << O.y;
					return 0;
				}
		}

    }
    cout << "No";
    return 0;
}
