#include <bits/stdc++.h>

using namespace std;

#define int long long

int tgcd(int a, int b) {
    while (b != 0) {
        tie(a, b) = make_pair(b, a % b);
    }
    return a;
}

struct Rational {
    int a, b;

    Rational() : a(0), b(1) {};
    Rational(int a, int b) : a(a), b(b) {};
    Rational(int a) : a(a), b(1) {};

    void simplify() {
        int g = tgcd(a, b);
        a /= g;
        b /= g;
    }

    bool valid() {
        return b != 0;
    }

    bool whole() {
        return valid() && (a % b == 0);
    }

    int toInt() {
        return a / b;
    }

    bool operator==(Rational other) {
        return a * other.b == b * other.a;
    }

    Rational operator+(Rational other) {
        return Rational { a * other.b + b * other.a, b * other.b };
    }

    Rational operator-(Rational other) {
        return Rational { a * other.b - b * other.a, b * other.b };
    }

    Rational operator-() {
        return Rational { -a, b };
    }

    Rational operator*(Rational other) {
        return Rational { a * other.a, b * other.b };
    }

    Rational operator/(Rational other) {
        return Rational { a * other.b, b * other.a };
    }
};

struct Line {
    Rational k, b;

    bool operator==(Line other) {
        return b == other.b && k == other.k;
    }

    bool vertical() {
        return !k.valid();
    }
};

struct Point {
    int x, y;
};

bool parallel(Line a, Line b) {
    if (a.vertical() && b.vertical()) return true;
    if (a.vertical() || b.vertical()) return false;
    return a.k == b.k;
}

bool intersect(Line a, Line b, Point& point) {
    if (parallel(a, b)) return false;
    if (b.vertical()) swap(a, b);
    if (a.vertical()) {
        auto x = a.b;
        auto y = b.k * x;
        y.simplify();
        y = y + b.b;
        if (x.whole() && y.whole()) {
            point.x = x.toInt();
            point.y = y.toInt();
            return true;
        } else {
            return false;
        }
    }
    auto x = b.b - a.b;
    x.simplify();
    auto z = a.k - b.k;
    z.simplify();
    x = x / z;
    x.simplify();
    auto y = b.k * x;
    y.simplify();
    y = y + b.b;
    y.simplify();
    if (x.whole() && y.whole()) {
        point.x = x.toInt();
        point.y = y.toInt();
        return true;
    } else {
        return false;
    }
}

Line makeline(Point a, Point b) {
    Line line;
    int rise = b.y - a.y;
    int run = b.x - a.x;
    line.k = Rational(rise, run);
    line.k.simplify();
    if (run != 0) {
        line.b = Rational(a.y) - line.k * a.x;
    } else {
        line.b = a.x;
    }
    line.b.simplify();
    return line;
}

int n;
vector<Point> points;
set<pair<int, int>> pt;

void check(int a, int b, int c, int d) {
    Point x;
    if (intersect(makeline(points[a], points[b]), makeline(points[c], points[d]), x)) {
        if (pt.find(make_pair(x.x, x.y)) != pt.end())
            return;
        cout << "Yes" << endl;
        cout << x.x << " " << x.y << endl;
        exit(0);
    }
}

int32_t main() {
    cin >> n;
    n *= 2;
    for (int i = 0; i < n; ++i) {
        Point point;
        cin >> point.x >> point.y;
        points.push_back(point);
        pt.insert(make_pair(point.x, point.y));
    }
    check(0, 1, 2, 3);
    check(0, 2, 1, 3);
    check(0, 3, 1, 2);
    cout << "No" << endl;
}