import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.util.Arrays;
import java.util.StringTokenizer;

public class B3 {

	public static class Vector implements Comparable<Vector> {
		long x;
		long y;

		public Vector(long x, long y) {
			this.x = x;
			this.y = y;
		}

		public String toString() {
			return x + " " + y;
		}

		public boolean Zero() {
			return x == 0 && y == 0;
		}

		public void normalise() {
			if (x < 0) {
				x = -x;
				y = -y;
			} else if (x == 0 && y < 0) {
				y = -y;
			}
		}

		public Vector subtract(Vector b) {
			return new Vector(x - b.x, y - b.y);
		}

		public Vector add(Vector b) {
			return new Vector(x + b.x, y + b.y);
		}

		@Override
		public int compareTo(Vector o) {
			if (y < 0 && o.y >= 0) {
				return -1;
			}
			if (y >= 0 && o.y < 0) {
				return 1;
			}
			long dp = x * o.y - y * o.x;
			if (dp > 0) {
				return 1;
			}
			if (dp < 0) {
				return -1;
			}
			return 0;
		}
	}

	public static class Line {
		long a;
		long b;
		long c;

		public Line(Vector m, Vector n) {
			if (m.x == n.x) {
				b = 0;
				a = 1;
				c = -m.x;
			} else if (m.y == n.y) {
				a = 0;
				b = 1;
				c = -m.y;
			} else {
				a = n.y - m.y;
				b = m.x - n.x;
				c = m.y * n.x - n.y * m.x;
			}
			normalise();
		}

		public void normalise() {
			if (a < 0) {
				a = -a;
				b = -b;
				c = -c;
			} else if (a == 0 && b < 0) {
				b = -b;
				c = -c;
			}
			long gcd = gcd(Math.abs(a), Math.abs(b));
			gcd = gcd(gcd, Math.abs(c));
			a /= gcd;
			b /= gcd;
			c /= gcd;
		}

		public Vector cross(Line x) {
			// if (a == 0 && x.a == 0) {
			// return null;
			// }
			// if (b == 0 && x.b == 0) {
			// return null;
			// }
			// long gcd1 = gcd(Math.abs(a), Math.abs(b));
			// long gcd2 = gcd(Math.abs(x.a), Math.abs(x.b));
			// if (a / gcd1 == x.a / gcd2 && b / gcd1 == b / gcd2) {
			// return null;
			// }
			long div = b * x.a - a * x.b;
			if (div == 0) {
				return null;
			}
			long vx = c * x.b - b * x.c;
			long vy = a * x.c - c * x.a;
			if (vx % div == 0 && vy % div == 0) {
				return new Vector(vx / div, vy / div);
			}
			return null;
		}
	}

	public static long gcd(long a, long b) {
		if (b == 0) {
			return a;
		}
		if (a == 0) {
			return b;
		}
		return gcd(b, a % b);
	}

	public static void main(String[] args) throws IOException {
		BufferedReader in = new BufferedReader(new InputStreamReader(System.in));
		PrintWriter out = new PrintWriter(System.out);
		StringTokenizer st = new StringTokenizer(in.readLine());
		int n = Integer.parseInt(st.nextToken());
		Vector[] v = new Vector[2 * n];
		for (int i = 0; i < v.length; i++) {
			st = new StringTokenizer(in.readLine());
			v[i] = new Vector(Long.parseLong(st.nextToken()), Long.parseLong(st.nextToken()));
		}
		int i = 0;
		for (int j = 0; j < v.length; j++) {
			if (j == i) {
				continue;
			}
			for (int i1 = 0; i1 < v.length; i1++) {
				if (i1 == i || i1 == j) {
					continue;
				}
				f: for (int j1 = 0; j1 < v.length; j1++) {
					if (j1 == i || j1 == j || j1 == i1) {
						continue;
					}
					Line a = new Line(v[i], v[j]);
					Line b = new Line(v[i1], v[j1]);
					// System.out.println(a.a + " " + a.b + " " + a.c);
					// System.out.println(b.a + " " + b.b + " " + b.c);
					// System.out.println();
					Vector cross = a.cross(b);
					if (cross == null) {
						continue;
					}
					if (Math.abs(cross.x) > 1000000 || Math.abs(cross.y) > 1000000) {
						continue;
					}
					Vector[] delta = new Vector[2 * n];
					// System.out.println(cross.toString());
					for (int k = 0; k < delta.length; k++) {
						delta[k] = v[k].subtract(cross);
						delta[k].normalise();
						// System.out.println(delta[k].toString());
						if (delta[k].Zero()) {
							continue f;
						}
					}
					Arrays.sort(delta);
					for (int k = 1; k < delta.length; k++) {
						if (k % 2 == 1 && delta[k].compareTo(delta[k - 1]) != 0) {
							continue f;
						}
						if (k % 2 == 0 && delta[k].compareTo(delta[k - 1]) == 0) {
							continue f;
						}
					}
					out.println("Yes");
					out.print(cross.toString());
					in.close();
					out.close();
					return;
				}
			}
		}
		out.println("No");
		in.close();
		out.close();
	}

}
